==> mozilla-source-0.9.8.tar.gz: mozilla/embedding/tests/mfcembed/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by mfcembed.rc
//
#define IDD_ABOUTBOX                    100
#define IDR_MAINFRAME                   128
#define IDR_MOZEMBTYPE                  129
#define IDR_CTXMENU_DOCUMENT            130
#define IDR_CTXMENU_LINK                131
#define IDR_CTXMENU_TEXT                132
#define IDR_CTXMENU_IMAGE               133
#define IDD_PROMPT_DIALOG               134
#define IDD_PROMPT_PASSWORD_DIALOG      135
#define IDD_PROMPT_USERPASS_DIALOG      136
#define IDD_PROFILES                    137
#define IDD_PROFILE_NEW                 138
#define IDD_PROFILE_RENAME              139
#define IDD_FINDDLG                     140
#define IDD_PRINT_PROGRESS_DIALOG       141
#define IDD_PREFS_START_PAGE            142
#define IDR_SECURITY_LOCK               143
#define IDR_SECURITY_UNLOCK             144
#define IDR_SECURITY_BROKEN             145
#define IDS_NOSECURITY_INFO             146
#define IDS_ENCRYPTION_HIGH_GRADE       147
#define IDS_ENCRYPTION_LOW_GRADE        148
#define IDS_ENCRYPTION_NONE             149
#define IDS_SRCH_STR_NOT_FOUND          150
#define IDD_PRINTSETUP_DIALOG           152
#define IDS_VIEW_FRAME_SOURCE           153
#define IDS_OPEN_FRAME_IN_NEW_WINDOW    154
#define ID_URL_BAR                      1001
#define ID_PROG_BAR                     1002
#define IDC_PROMPT_ANSWER               1003
#define IDC_PROMPT_QUESTION             1004
#define IDC_PROMPT_TEXT                 1005
#define IDC_USERNAME                    1006
#define IDC_PASSWORD                    1007
#define IDC_CHECK_SAVE_PASSWORD         1008
#define IDC_USERNAME_LABEL              1009
#define IDC_PASSWORD_LABEL              1010
#define IDC_LIST1                       1011
#define IDC_PROF_RENAME                 1012
#define IDC_PROF_DELETE                 1013
#define IDC_PROF_NEW                    1014
#define IDC_CHECK_ASK_AT_START          1015
#define IDC_NEW_PROF_NAME               1016
#define IDC_LOCALE_COMBO                1017
#define IDC_NEW_NAME                    1018
#define IDC_PPD_DOC_TXT                 1020
#define IDC_PPD_DOC_TITLE_STATIC        1021
#define IDC_LEFT_MARGIN_TXT             1022
#define IDC_TOP_MARGIN_TXT              1023
#define IDC_BOTTOM_MARGIN_TXT           1024
#define IDC_RIGHT_MARGIN_TXT            1026
#define IDC_PRT_BGCOLORS                1027
#define IDC_SCALE                       1028
#define IDC_SCALE_TXT                   1030
#define IDC_PRT_BGIMAGES                1031
#define IDC_PAPER_SIZE_CBX              1032
#define IDC_UD_PAPER_HGT                1033
#define IDC_UD_PAPER_WDTH               1034
#define IDC_UD_WIDTH_LBL                1035
#define IDC_UD_HEIGHT_LBL               1036
#define IDC_INCHES_RD                   1037
#define IDC_MILLI_RD                    1038
#define IDC_HDR_LEFT_TXT                1039
#define IDC_MATCH_WHOLE_WORD            1040
#define IDC_HDR_MID_TXT                 1040
#define IDC_MATCH_CASE                  1041
#define IDC_HDR_RIGHT_TXT               1041
#define IDC_WRAP_AROUND                 1042
#define IDC_FTR_LEFT_TXT                1042
#define IDC_SEARCH_BACKWARDS            1043
#define IDC_FTR_MID_TXT                 1043
#define IDC_FTR_RIGHT_TXT               1044
#define IDC_FIND_EDIT                   1152
#define IDC_RADIO_BLANK_PAGE            1153
#define IDC_RADIO_HOME_PAGE             1154
#define IDC_EDIT_HOMEPAGE               1155
#define ID_NAV_BACK                     32773
#define ID_NAV_FORWARD                  32774
#define ID_NAV_HOME                     32775
#define ID_NAV_STOP                     32776
#define ID_NAV_RELOAD                   32777
#define ID_EDIT_SELECT_NONE             32778
#define ID_NEW_BROWSER                  32779
#define ID_VIEW_SOURCE                  32780
#define ID_VIEW_INFO                    32781
#define ID_VIEW_IMAGE                   32782
#define ID_OPEN_LINK_IN_NEW_WINDOW      32783
#define ID_SAVE_LINK_AS                 32784
#define ID_SAVE_IMAGE_AS                32785
#define ID_COPY_LINK_LOCATION           32786
#define ID_MANAGE_PROFILES              32787
#define ID_EDIT_PREFERENCES             32788
#define ID_FILE_PRINTPREVIEW            32789
#define ID_FILE_PRINTSETUP              32790
#define ID_VIEW_FRAME_SOURCE            32791
#define ID_OPEN_FRAME_IN_NEW_WINDOW     32792

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_3D_CONTROLS                     1
#define _APS_NEXT_RESOURCE_VALUE        155
#define _APS_NEXT_COMMAND_VALUE         32793
#define _APS_NEXT_CONTROL_VALUE         1042
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

==> mozilla-source-1.1b.tar.gz: mozilla/embedding/tests/mfcembed/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by mfcembed.rc
//
#define IDD_ABOUTBOX                    100
#define ID_TOOLBAR_UPDATE               101
#define IDR_MAINFRAME                   128
#define IDR_MOZEMBTYPE                  129
#define IDR_EDITOR                      129
#define IDR_CTXMENU_DOCUMENT            130
#define IDR_CTXMENU_LINK                131
#define IDR_CTXMENU_TEXT                132
#define IDR_CTXMENU_IMAGE               133
#define IDD_PROMPT_DIALOG               134
#define IDD_PROMPT_PASSWORD_DIALOG      135
#define IDD_PROMPT_USERPASS_DIALOG      136
#define IDD_PROFILES                    137
#define IDD_PROFILE_NEW                 138
#define IDD_PROFILE_RENAME              139
#define IDD_FINDDLG                     140
#define IDD_PREFS_START_PAGE            142
#define IDR_SECURITY_LOCK               143
#define IDR_SECURITY_UNLOCK             144
#define IDR_SECURITY_BROKEN             145
#define IDS_NOSECURITY_INFO             146
#define IDS_ENCRYPTION_HIGH_GRADE       147
#define IDS_ENCRYPTION_LOW_GRADE        148
#define IDS_ENCRYPTION_NONE             149
#define IDS_SRCH_STR_NOT_FOUND          150
#define IDD_PRINTSETUP_DIALOG           152
#define IDS_VIEW_FRAME_SOURCE           153
#define IDS_OPEN_FRAME_IN_NEW_WINDOW    154
#define IDR_CTXMENU_EDITOR              155
#define IDD_HEADERFOOTER_TAB            156
#define IDD_FORMAT_OPTIONS_TAB          157
#define IDD_CUSTOM_PROMPT_DIALOG        159
#define ID_URL_BAR                      1001
#define ID_PROG_BAR                     1002
#define IDC_PROMPT_ANSWER               1003
#define IDC_PROMPT_QUESTION             1004
#define IDC_PROMPT_TEXT                 1005
#define IDC_USERNAME                    1006
#define IDC_PASSWORD                    1007
#define IDC_CHECK_SAVE_PASSWORD         1008
#define IDC_USERNAME_LABEL              1009
#define IDC_PASSWORD_LABEL              1010
#define IDC_LIST1                       1011
#define IDC_PROF_RENAME                 1012
#define IDC_PROF_DELETE                 1013
#define IDC_PROF_NEW                    1014
#define IDC_CHECK_ASK_AT_START          1015
#define IDC_NEW_PROF_NAME               1016
#define IDC_LOCALE_COMBO                1017
#define IDC_NEW_NAME                    1018
#define IDC_PPD_DOC_TXT                 1020
#define IDC_PPD_DOC_TITLE_STATIC        1021
#define IDC_LEFT_MARGIN_TXT             1022
#define IDC_TOP_MARGIN_TXT              1023
#define IDC_BOTTOM_MARGIN_TXT           1024
#define IDC_RIGHT_MARGIN_TXT            1026
#define IDC_PRT_BGCOLORS                1027
#define IDC_SCALE                       1028
#define IDC_SCALE_TXT                   1030
#define IDC_PRT_BGIMAGES                1031
#define IDC_PAPER_SIZE_CBX              1032
#define IDC_UD_PAPER_HGT                1033
#define IDC_UD_PAPER_WDTH               1034
#define IDC_UD_WIDTH_LBL                1035
#define IDC_UD_HEIGHT_LBL               1036
#define IDC_INCHES_RD                   1037
#define IDC_MILLI_RD                    1038
#define IDC_HDR_LEFT_TXT                1039
#define IDC_MATCH_WHOLE_WORD            1040
#define IDC_HDR_MID_TXT                 1040
#define IDC_MATCH_CASE                  1041
#define IDC_HDR_RIGHT_TXT               1041
#define IDC_WRAP_AROUND                 1042
#define IDC_FTR_LEFT_TXT                1042
#define IDC_TAB1                        1042
#define IDC_PRINTSETUP_TAB_CTRL         1042
#define IDC_SEARCH_BACKWARDS            1043
#define IDC_FTR_MID_TXT                 1043
#define IDC_FTR_RIGHT_TXT               1044
#define IDC_FTR_LEFT_CMBX               1045
#define IDC_FTR_CENTER_CMBX             1047
#define IDC_FTR_RIGHT_CMBX              1048
#define IDC_HDR_LEFT_CMBX               1049
#define IDC_HDR_CENTER_CMBX             1050
#define IDC_HDR_RIGHT_CMBX              1051
#define IDC_FIND_EDIT                   1052
#define IDC_RADIO_BLANK_PAGE            1053
#define IDC_RADIO_HOME_PAGE             1054
#define IDC_EDIT_HOMEPAGE               1055
#define IDC_PRT_PORTRAIT_RD             1056
#define IDC_PRT_LANDSCAPE_RD            1057
#define ID_NAV_BACK                     32773
#define ID_NAV_FORWARD                  32774
#define ID_NAV_HOME                     32775
#define ID_NAV_STOP                     32776
#define ID_NAV_RELOAD                   32777
#define ID_EDIT_SELECT_NONE             32778
#define ID_NEW_BROWSER                  32779
#define ID_VIEW_SOURCE                  32780
#define ID_VIEW_INFO                    32781
#define ID_VIEW_IMAGE                   32782
#define ID_OPEN_LINK_IN_NEW_WINDOW      32783
#define ID_SAVE_LINK_AS                 32784
#define ID_SAVE_IMAGE_AS                32785
#define ID_COPY_LINK_LOCATION           32786
#define ID_MANAGE_PROFILES              32787
#define ID_EDIT_PREFERENCES             32788
#define ID_FILE_PRINTPREVIEW            32789
#define ID_FILE_PRINTSETUP              32790
#define ID_VIEW_FRAME_SOURCE            32791
#define ID_OPEN_FRAME_IN_NEW_WINDOW     32792
#define ID_BOLD                         32793
#define ID_UNDERLINE                    32794
#define ID_ITALICS                      32795
#define ID_NEW_EDITORWINDOW             32796
#define ID_INDENT                       32797
#define ID_OUTDENT                      32798
#define ID_FONTBLACK                    32799
#define ID_FONTRED                      32800
#define ID_BGCOLOR                      32801
#define ID_NOBGCOLOR                    32802
#define ID_FONTSIZEINCREASE             32803
#define ID_FONTSIZEDECREASE             32804
#define ID_ARIAL                        32805
#define ID_TIMES                        32806
#define ID_COURIER                      32807
#define ID_ALIGNLEFT                    32808
#define ID_ALIGNCENTER                  32809
#define ID_ALIGNRIGHT                   32810
#define ID_INSERTLINK                   32811
#define ID_EDITOR_UNDO                  32813
#define ID_EDITOR_REDO                  32814


// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_3D_CONTROLS                     1
#define _APS_NEXT_RESOURCE_VALUE        160
#define _APS_NEXT_COMMAND_VALUE         32815
#define _APS_NEXT_CONTROL_VALUE         1058
#define _APS_NEXT_SYMED_VALUE           102
#endif
#endif
